@@ -81,8 +81,9 @@ class Node(metaclass=abc.ABCMeta):
                         msgs = await osub.fetch(timeout=self.conf.nats.sub_conf.pull_timeout)
                         msg = msgs[0]
                         await self._callback(msg)
-                    except TimeoutError:
-                        break
+                    except TimeoutError as e:
+                        logger.exception(e)
+                        continue
             else:
                 # 推送模式
                 osub = await self.js.subscribe(
@@ -103,8 +104,9 @@ class Node(metaclass=abc.ABCMeta):
                     try:
                         msg = await osub.next_msg()
                         await self._callback(msg)
-                    except TimeoutError:
-                        break
+                    except TimeoutError as e:
+                        logger.exception(e)
+                        continue
         else:
             # 没订阅任何主题时
             while True:
